# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventModelV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'location_id': 'str',
        'window_id': 'str',
        'date_occurred': 'datetime',
        'description': 'str',
        'reason': 'str',
        'content_type': 'CaseContentTypeForApi',
        'attachment': 'AttachmentModelV3',
        'code_ids': 'list[str]',
        'tag_details': 'list[str]',
        'document_url': 'str',
        'document_name': 'str',
        'title': 'str',
        'evidence_indicator_id': 'str',
        'created': 'datetime',
        'created_by': 'str',
        'modified': 'datetime',
        'modified_by': 'str',
        'savings': 'float',
        'group_name': 'str',
        'group_path': 'str',
        'group_type': 'GroupTypeCodesForApi'
    }

    attribute_map = {
        'id': 'Id',
        'location_id': 'LocationId',
        'window_id': 'WindowId',
        'date_occurred': 'DateOccurred',
        'description': 'Description',
        'reason': 'Reason',
        'content_type': 'ContentType',
        'attachment': 'Attachment',
        'code_ids': 'CodeIds',
        'tag_details': 'TagDetails',
        'document_url': 'DocumentUrl',
        'document_name': 'DocumentName',
        'title': 'Title',
        'evidence_indicator_id': 'EvidenceIndicatorId',
        'created': 'Created',
        'created_by': 'CreatedBy',
        'modified': 'Modified',
        'modified_by': 'ModifiedBy',
        'savings': 'Savings',
        'group_name': 'GroupName',
        'group_path': 'GroupPath',
        'group_type': 'GroupType'
    }

    def __init__(self, id=None, location_id=None, window_id=None, date_occurred=None, description=None, reason=None, content_type=None, attachment=None, code_ids=None, tag_details=None, document_url=None, document_name=None, title=None, evidence_indicator_id=None, created=None, created_by=None, modified=None, modified_by=None, savings=None, group_name=None, group_path=None, group_type=None):  # noqa: E501
        """EventModelV3 - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._location_id = None
        self._window_id = None
        self._date_occurred = None
        self._description = None
        self._reason = None
        self._content_type = None
        self._attachment = None
        self._code_ids = None
        self._tag_details = None
        self._document_url = None
        self._document_name = None
        self._title = None
        self._evidence_indicator_id = None
        self._created = None
        self._created_by = None
        self._modified = None
        self._modified_by = None
        self._savings = None
        self._group_name = None
        self._group_path = None
        self._group_type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if location_id is not None:
            self.location_id = location_id
        if window_id is not None:
            self.window_id = window_id
        self.date_occurred = date_occurred
        if description is not None:
            self.description = description
        if reason is not None:
            self.reason = reason
        self.content_type = content_type
        self.attachment = attachment
        if code_ids is not None:
            self.code_ids = code_ids
        if tag_details is not None:
            self.tag_details = tag_details
        if document_url is not None:
            self.document_url = document_url
        if document_name is not None:
            self.document_name = document_name
        if title is not None:
            self.title = title
        if evidence_indicator_id is not None:
            self.evidence_indicator_id = evidence_indicator_id
        if created is not None:
            self.created = created
        if created_by is not None:
            self.created_by = created_by
        if modified is not None:
            self.modified = modified
        if modified_by is not None:
            self.modified_by = modified_by
        if savings is not None:
            self.savings = savings
        if group_name is not None:
            self.group_name = group_name
        if group_path is not None:
            self.group_path = group_path
        if group_type is not None:
            self.group_type = group_type

    @property
    def id(self):
        """Gets the id of this EventModelV3.  # noqa: E501


        :return: The id of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EventModelV3.


        :param id: The id of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def location_id(self):
        """Gets the location_id of this EventModelV3.  # noqa: E501


        :return: The location_id of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this EventModelV3.


        :param location_id: The location_id of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def window_id(self):
        """Gets the window_id of this EventModelV3.  # noqa: E501


        :return: The window_id of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._window_id

    @window_id.setter
    def window_id(self, window_id):
        """Sets the window_id of this EventModelV3.


        :param window_id: The window_id of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._window_id = window_id

    @property
    def date_occurred(self):
        """Gets the date_occurred of this EventModelV3.  # noqa: E501


        :return: The date_occurred of this EventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._date_occurred

    @date_occurred.setter
    def date_occurred(self, date_occurred):
        """Sets the date_occurred of this EventModelV3.


        :param date_occurred: The date_occurred of this EventModelV3.  # noqa: E501
        :type: datetime
        """
        if date_occurred is None:
            raise ValueError("Invalid value for `date_occurred`, must not be `None`")  # noqa: E501

        self._date_occurred = date_occurred

    @property
    def description(self):
        """Gets the description of this EventModelV3.  # noqa: E501


        :return: The description of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this EventModelV3.


        :param description: The description of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def reason(self):
        """Gets the reason of this EventModelV3.  # noqa: E501


        :return: The reason of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this EventModelV3.


        :param reason: The reason of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def content_type(self):
        """Gets the content_type of this EventModelV3.  # noqa: E501


        :return: The content_type of this EventModelV3.  # noqa: E501
        :rtype: CaseContentTypeForApi
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this EventModelV3.


        :param content_type: The content_type of this EventModelV3.  # noqa: E501
        :type: CaseContentTypeForApi
        """
        if content_type is None:
            raise ValueError("Invalid value for `content_type`, must not be `None`")  # noqa: E501

        self._content_type = content_type

    @property
    def attachment(self):
        """Gets the attachment of this EventModelV3.  # noqa: E501


        :return: The attachment of this EventModelV3.  # noqa: E501
        :rtype: AttachmentModelV3
        """
        return self._attachment

    @attachment.setter
    def attachment(self, attachment):
        """Sets the attachment of this EventModelV3.


        :param attachment: The attachment of this EventModelV3.  # noqa: E501
        :type: AttachmentModelV3
        """
        if attachment is None:
            raise ValueError("Invalid value for `attachment`, must not be `None`")  # noqa: E501

        self._attachment = attachment

    @property
    def code_ids(self):
        """Gets the code_ids of this EventModelV3.  # noqa: E501


        :return: The code_ids of this EventModelV3.  # noqa: E501
        :rtype: list[str]
        """
        return self._code_ids

    @code_ids.setter
    def code_ids(self, code_ids):
        """Sets the code_ids of this EventModelV3.


        :param code_ids: The code_ids of this EventModelV3.  # noqa: E501
        :type: list[str]
        """

        self._code_ids = code_ids

    @property
    def tag_details(self):
        """Gets the tag_details of this EventModelV3.  # noqa: E501


        :return: The tag_details of this EventModelV3.  # noqa: E501
        :rtype: list[str]
        """
        return self._tag_details

    @tag_details.setter
    def tag_details(self, tag_details):
        """Sets the tag_details of this EventModelV3.


        :param tag_details: The tag_details of this EventModelV3.  # noqa: E501
        :type: list[str]
        """

        self._tag_details = tag_details

    @property
    def document_url(self):
        """Gets the document_url of this EventModelV3.  # noqa: E501


        :return: The document_url of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """Sets the document_url of this EventModelV3.


        :param document_url: The document_url of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._document_url = document_url

    @property
    def document_name(self):
        """Gets the document_name of this EventModelV3.  # noqa: E501


        :return: The document_name of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._document_name

    @document_name.setter
    def document_name(self, document_name):
        """Sets the document_name of this EventModelV3.


        :param document_name: The document_name of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._document_name = document_name

    @property
    def title(self):
        """Gets the title of this EventModelV3.  # noqa: E501


        :return: The title of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this EventModelV3.


        :param title: The title of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def evidence_indicator_id(self):
        """Gets the evidence_indicator_id of this EventModelV3.  # noqa: E501


        :return: The evidence_indicator_id of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._evidence_indicator_id

    @evidence_indicator_id.setter
    def evidence_indicator_id(self, evidence_indicator_id):
        """Sets the evidence_indicator_id of this EventModelV3.


        :param evidence_indicator_id: The evidence_indicator_id of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._evidence_indicator_id = evidence_indicator_id

    @property
    def created(self):
        """Gets the created of this EventModelV3.  # noqa: E501


        :return: The created of this EventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this EventModelV3.


        :param created: The created of this EventModelV3.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def created_by(self):
        """Gets the created_by of this EventModelV3.  # noqa: E501


        :return: The created_by of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this EventModelV3.


        :param created_by: The created_by of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified(self):
        """Gets the modified of this EventModelV3.  # noqa: E501


        :return: The modified of this EventModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this EventModelV3.


        :param modified: The modified of this EventModelV3.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def modified_by(self):
        """Gets the modified_by of this EventModelV3.  # noqa: E501


        :return: The modified_by of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this EventModelV3.


        :param modified_by: The modified_by of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def savings(self):
        """Gets the savings of this EventModelV3.  # noqa: E501


        :return: The savings of this EventModelV3.  # noqa: E501
        :rtype: float
        """
        return self._savings

    @savings.setter
    def savings(self, savings):
        """Sets the savings of this EventModelV3.


        :param savings: The savings of this EventModelV3.  # noqa: E501
        :type: float
        """

        self._savings = savings

    @property
    def group_name(self):
        """Gets the group_name of this EventModelV3.  # noqa: E501


        :return: The group_name of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this EventModelV3.


        :param group_name: The group_name of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._group_name = group_name

    @property
    def group_path(self):
        """Gets the group_path of this EventModelV3.  # noqa: E501


        :return: The group_path of this EventModelV3.  # noqa: E501
        :rtype: str
        """
        return self._group_path

    @group_path.setter
    def group_path(self, group_path):
        """Sets the group_path of this EventModelV3.


        :param group_path: The group_path of this EventModelV3.  # noqa: E501
        :type: str
        """

        self._group_path = group_path

    @property
    def group_type(self):
        """Gets the group_type of this EventModelV3.  # noqa: E501


        :return: The group_type of this EventModelV3.  # noqa: E501
        :rtype: GroupTypeCodesForApi
        """
        return self._group_type

    @group_type.setter
    def group_type(self, group_type):
        """Sets the group_type of this EventModelV3.


        :param group_type: The group_type of this EventModelV3.  # noqa: E501
        :type: GroupTypeCodesForApi
        """

        self._group_type = group_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventModelV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventModelV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NodeSettingOverview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'update_interval': 'NodeSettingValues',
        'decimation_factor': 'NodeSettingValues',
        'operating_mode_pressure': 'NodeSettingValues',
        'operating_mode_vibration': 'NodeSettingValues',
        'number_of_samples': 'NodeSettingValues',
        'compression_type': 'NodeSettingValues'
    }

    attribute_map = {
        'update_interval': 'UpdateInterval',
        'decimation_factor': 'DecimationFactor',
        'operating_mode_pressure': 'OperatingModePressure',
        'operating_mode_vibration': 'OperatingModeVibration',
        'number_of_samples': 'NumberOfSamples',
        'compression_type': 'CompressionType'
    }

    def __init__(self, update_interval=None, decimation_factor=None, operating_mode_pressure=None, operating_mode_vibration=None, number_of_samples=None, compression_type=None):  # noqa: E501
        """NodeSettingOverview - a model defined in Swagger"""  # noqa: E501
        self._update_interval = None
        self._decimation_factor = None
        self._operating_mode_pressure = None
        self._operating_mode_vibration = None
        self._number_of_samples = None
        self._compression_type = None
        self.discriminator = None
        if update_interval is not None:
            self.update_interval = update_interval
        if decimation_factor is not None:
            self.decimation_factor = decimation_factor
        if operating_mode_pressure is not None:
            self.operating_mode_pressure = operating_mode_pressure
        if operating_mode_vibration is not None:
            self.operating_mode_vibration = operating_mode_vibration
        if number_of_samples is not None:
            self.number_of_samples = number_of_samples
        if compression_type is not None:
            self.compression_type = compression_type

    @property
    def update_interval(self):
        """Gets the update_interval of this NodeSettingOverview.  # noqa: E501


        :return: The update_interval of this NodeSettingOverview.  # noqa: E501
        :rtype: NodeSettingValues
        """
        return self._update_interval

    @update_interval.setter
    def update_interval(self, update_interval):
        """Sets the update_interval of this NodeSettingOverview.


        :param update_interval: The update_interval of this NodeSettingOverview.  # noqa: E501
        :type: NodeSettingValues
        """

        self._update_interval = update_interval

    @property
    def decimation_factor(self):
        """Gets the decimation_factor of this NodeSettingOverview.  # noqa: E501


        :return: The decimation_factor of this NodeSettingOverview.  # noqa: E501
        :rtype: NodeSettingValues
        """
        return self._decimation_factor

    @decimation_factor.setter
    def decimation_factor(self, decimation_factor):
        """Sets the decimation_factor of this NodeSettingOverview.


        :param decimation_factor: The decimation_factor of this NodeSettingOverview.  # noqa: E501
        :type: NodeSettingValues
        """

        self._decimation_factor = decimation_factor

    @property
    def operating_mode_pressure(self):
        """Gets the operating_mode_pressure of this NodeSettingOverview.  # noqa: E501


        :return: The operating_mode_pressure of this NodeSettingOverview.  # noqa: E501
        :rtype: NodeSettingValues
        """
        return self._operating_mode_pressure

    @operating_mode_pressure.setter
    def operating_mode_pressure(self, operating_mode_pressure):
        """Sets the operating_mode_pressure of this NodeSettingOverview.


        :param operating_mode_pressure: The operating_mode_pressure of this NodeSettingOverview.  # noqa: E501
        :type: NodeSettingValues
        """

        self._operating_mode_pressure = operating_mode_pressure

    @property
    def operating_mode_vibration(self):
        """Gets the operating_mode_vibration of this NodeSettingOverview.  # noqa: E501


        :return: The operating_mode_vibration of this NodeSettingOverview.  # noqa: E501
        :rtype: NodeSettingValues
        """
        return self._operating_mode_vibration

    @operating_mode_vibration.setter
    def operating_mode_vibration(self, operating_mode_vibration):
        """Sets the operating_mode_vibration of this NodeSettingOverview.


        :param operating_mode_vibration: The operating_mode_vibration of this NodeSettingOverview.  # noqa: E501
        :type: NodeSettingValues
        """

        self._operating_mode_vibration = operating_mode_vibration

    @property
    def number_of_samples(self):
        """Gets the number_of_samples of this NodeSettingOverview.  # noqa: E501


        :return: The number_of_samples of this NodeSettingOverview.  # noqa: E501
        :rtype: NodeSettingValues
        """
        return self._number_of_samples

    @number_of_samples.setter
    def number_of_samples(self, number_of_samples):
        """Sets the number_of_samples of this NodeSettingOverview.


        :param number_of_samples: The number_of_samples of this NodeSettingOverview.  # noqa: E501
        :type: NodeSettingValues
        """

        self._number_of_samples = number_of_samples

    @property
    def compression_type(self):
        """Gets the compression_type of this NodeSettingOverview.  # noqa: E501


        :return: The compression_type of this NodeSettingOverview.  # noqa: E501
        :rtype: NodeSettingValues
        """
        return self._compression_type

    @compression_type.setter
    def compression_type(self, compression_type):
        """Sets the compression_type of this NodeSettingOverview.


        :param compression_type: The compression_type of this NodeSettingOverview.  # noqa: E501
        :type: NodeSettingValues
        """

        self._compression_type = compression_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeSettingOverview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeSettingOverview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HardwareStatusResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'location_hardware_statuses': 'list[HardwareStatusChild]',
        'total_hardware_count': 'int',
        'total_unassigned_count': 'int',
        'total_online_count': 'int',
        'total_offline_count': 'int'
    }

    attribute_map = {
        'location_hardware_statuses': 'LocationHardwareStatuses',
        'total_hardware_count': 'TotalHardwareCount',
        'total_unassigned_count': 'TotalUnassignedCount',
        'total_online_count': 'TotalOnlineCount',
        'total_offline_count': 'TotalOfflineCount'
    }

    def __init__(self, location_hardware_statuses=None, total_hardware_count=None, total_unassigned_count=None, total_online_count=None, total_offline_count=None):  # noqa: E501
        """HardwareStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._location_hardware_statuses = None
        self._total_hardware_count = None
        self._total_unassigned_count = None
        self._total_online_count = None
        self._total_offline_count = None
        self.discriminator = None
        if location_hardware_statuses is not None:
            self.location_hardware_statuses = location_hardware_statuses
        if total_hardware_count is not None:
            self.total_hardware_count = total_hardware_count
        if total_unassigned_count is not None:
            self.total_unassigned_count = total_unassigned_count
        if total_online_count is not None:
            self.total_online_count = total_online_count
        if total_offline_count is not None:
            self.total_offline_count = total_offline_count

    @property
    def location_hardware_statuses(self):
        """Gets the location_hardware_statuses of this HardwareStatusResponse.  # noqa: E501


        :return: The location_hardware_statuses of this HardwareStatusResponse.  # noqa: E501
        :rtype: list[HardwareStatusChild]
        """
        return self._location_hardware_statuses

    @location_hardware_statuses.setter
    def location_hardware_statuses(self, location_hardware_statuses):
        """Sets the location_hardware_statuses of this HardwareStatusResponse.


        :param location_hardware_statuses: The location_hardware_statuses of this HardwareStatusResponse.  # noqa: E501
        :type: list[HardwareStatusChild]
        """

        self._location_hardware_statuses = location_hardware_statuses

    @property
    def total_hardware_count(self):
        """Gets the total_hardware_count of this HardwareStatusResponse.  # noqa: E501


        :return: The total_hardware_count of this HardwareStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_hardware_count

    @total_hardware_count.setter
    def total_hardware_count(self, total_hardware_count):
        """Sets the total_hardware_count of this HardwareStatusResponse.


        :param total_hardware_count: The total_hardware_count of this HardwareStatusResponse.  # noqa: E501
        :type: int
        """

        self._total_hardware_count = total_hardware_count

    @property
    def total_unassigned_count(self):
        """Gets the total_unassigned_count of this HardwareStatusResponse.  # noqa: E501


        :return: The total_unassigned_count of this HardwareStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_unassigned_count

    @total_unassigned_count.setter
    def total_unassigned_count(self, total_unassigned_count):
        """Sets the total_unassigned_count of this HardwareStatusResponse.


        :param total_unassigned_count: The total_unassigned_count of this HardwareStatusResponse.  # noqa: E501
        :type: int
        """

        self._total_unassigned_count = total_unassigned_count

    @property
    def total_online_count(self):
        """Gets the total_online_count of this HardwareStatusResponse.  # noqa: E501


        :return: The total_online_count of this HardwareStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_online_count

    @total_online_count.setter
    def total_online_count(self, total_online_count):
        """Sets the total_online_count of this HardwareStatusResponse.


        :param total_online_count: The total_online_count of this HardwareStatusResponse.  # noqa: E501
        :type: int
        """

        self._total_online_count = total_online_count

    @property
    def total_offline_count(self):
        """Gets the total_offline_count of this HardwareStatusResponse.  # noqa: E501


        :return: The total_offline_count of this HardwareStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_offline_count

    @total_offline_count.setter
    def total_offline_count(self, total_offline_count):
        """Sets the total_offline_count of this HardwareStatusResponse.


        :param total_offline_count: The total_offline_count of this HardwareStatusResponse.  # noqa: E501
        :type: int
        """

        self._total_offline_count = total_offline_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HardwareStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HardwareStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HardwareStatusChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'location_id': 'str',
        'location_name': 'str',
        'location_abbreviation': 'str',
        'hardware_count': 'int',
        'unassigned_count': 'int',
        'online_count': 'int',
        'offline_count': 'int'
    }

    attribute_map = {
        'location_id': 'LocationId',
        'location_name': 'LocationName',
        'location_abbreviation': 'LocationAbbreviation',
        'hardware_count': 'HardwareCount',
        'unassigned_count': 'UnassignedCount',
        'online_count': 'OnlineCount',
        'offline_count': 'OfflineCount'
    }

    def __init__(self, location_id=None, location_name=None, location_abbreviation=None, hardware_count=None, unassigned_count=None, online_count=None, offline_count=None):  # noqa: E501
        """HardwareStatusChild - a model defined in Swagger"""  # noqa: E501
        self._location_id = None
        self._location_name = None
        self._location_abbreviation = None
        self._hardware_count = None
        self._unassigned_count = None
        self._online_count = None
        self._offline_count = None
        self.discriminator = None
        if location_id is not None:
            self.location_id = location_id
        if location_name is not None:
            self.location_name = location_name
        if location_abbreviation is not None:
            self.location_abbreviation = location_abbreviation
        if hardware_count is not None:
            self.hardware_count = hardware_count
        if unassigned_count is not None:
            self.unassigned_count = unassigned_count
        if online_count is not None:
            self.online_count = online_count
        if offline_count is not None:
            self.offline_count = offline_count

    @property
    def location_id(self):
        """Gets the location_id of this HardwareStatusChild.  # noqa: E501


        :return: The location_id of this HardwareStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this HardwareStatusChild.


        :param location_id: The location_id of this HardwareStatusChild.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def location_name(self):
        """Gets the location_name of this HardwareStatusChild.  # noqa: E501


        :return: The location_name of this HardwareStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """Sets the location_name of this HardwareStatusChild.


        :param location_name: The location_name of this HardwareStatusChild.  # noqa: E501
        :type: str
        """

        self._location_name = location_name

    @property
    def location_abbreviation(self):
        """Gets the location_abbreviation of this HardwareStatusChild.  # noqa: E501


        :return: The location_abbreviation of this HardwareStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._location_abbreviation

    @location_abbreviation.setter
    def location_abbreviation(self, location_abbreviation):
        """Sets the location_abbreviation of this HardwareStatusChild.


        :param location_abbreviation: The location_abbreviation of this HardwareStatusChild.  # noqa: E501
        :type: str
        """

        self._location_abbreviation = location_abbreviation

    @property
    def hardware_count(self):
        """Gets the hardware_count of this HardwareStatusChild.  # noqa: E501


        :return: The hardware_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._hardware_count

    @hardware_count.setter
    def hardware_count(self, hardware_count):
        """Sets the hardware_count of this HardwareStatusChild.


        :param hardware_count: The hardware_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._hardware_count = hardware_count

    @property
    def unassigned_count(self):
        """Gets the unassigned_count of this HardwareStatusChild.  # noqa: E501


        :return: The unassigned_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._unassigned_count

    @unassigned_count.setter
    def unassigned_count(self, unassigned_count):
        """Sets the unassigned_count of this HardwareStatusChild.


        :param unassigned_count: The unassigned_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._unassigned_count = unassigned_count

    @property
    def online_count(self):
        """Gets the online_count of this HardwareStatusChild.  # noqa: E501


        :return: The online_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._online_count

    @online_count.setter
    def online_count(self, online_count):
        """Sets the online_count of this HardwareStatusChild.


        :param online_count: The online_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._online_count = online_count

    @property
    def offline_count(self):
        """Gets the offline_count of this HardwareStatusChild.  # noqa: E501


        :return: The offline_count of this HardwareStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._offline_count

    @offline_count.setter
    def offline_count(self, offline_count):
        """Sets the offline_count of this HardwareStatusChild.


        :param offline_count: The offline_count of this HardwareStatusChild.  # noqa: E501
        :type: int
        """

        self._offline_count = offline_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HardwareStatusChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HardwareStatusChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TreeItemAvailableAssetClassResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tree_item': 'TreeItemChild',
        'asset_class_code': 'str',
        'asset_type': 'AssetTypeChild',
        'asset_category': 'AssetCategoryChild',
        'asset_size': 'AssetSizeChild'
    }

    attribute_map = {
        'tree_item': 'TreeItem',
        'asset_class_code': 'AssetClassCode',
        'asset_type': 'AssetType',
        'asset_category': 'AssetCategory',
        'asset_size': 'AssetSize'
    }

    def __init__(self, tree_item=None, asset_class_code=None, asset_type=None, asset_category=None, asset_size=None):  # noqa: E501
        """TreeItemAvailableAssetClassResponse - a model defined in Swagger"""  # noqa: E501
        self._tree_item = None
        self._asset_class_code = None
        self._asset_type = None
        self._asset_category = None
        self._asset_size = None
        self.discriminator = None
        if tree_item is not None:
            self.tree_item = tree_item
        if asset_class_code is not None:
            self.asset_class_code = asset_class_code
        if asset_type is not None:
            self.asset_type = asset_type
        if asset_category is not None:
            self.asset_category = asset_category
        if asset_size is not None:
            self.asset_size = asset_size

    @property
    def tree_item(self):
        """Gets the tree_item of this TreeItemAvailableAssetClassResponse.  # noqa: E501


        :return: The tree_item of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :rtype: TreeItemChild
        """
        return self._tree_item

    @tree_item.setter
    def tree_item(self, tree_item):
        """Sets the tree_item of this TreeItemAvailableAssetClassResponse.


        :param tree_item: The tree_item of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :type: TreeItemChild
        """

        self._tree_item = tree_item

    @property
    def asset_class_code(self):
        """Gets the asset_class_code of this TreeItemAvailableAssetClassResponse.  # noqa: E501


        :return: The asset_class_code of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :rtype: str
        """
        return self._asset_class_code

    @asset_class_code.setter
    def asset_class_code(self, asset_class_code):
        """Sets the asset_class_code of this TreeItemAvailableAssetClassResponse.


        :param asset_class_code: The asset_class_code of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :type: str
        """

        self._asset_class_code = asset_class_code

    @property
    def asset_type(self):
        """Gets the asset_type of this TreeItemAvailableAssetClassResponse.  # noqa: E501


        :return: The asset_type of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :rtype: AssetTypeChild
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this TreeItemAvailableAssetClassResponse.


        :param asset_type: The asset_type of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :type: AssetTypeChild
        """

        self._asset_type = asset_type

    @property
    def asset_category(self):
        """Gets the asset_category of this TreeItemAvailableAssetClassResponse.  # noqa: E501


        :return: The asset_category of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :rtype: AssetCategoryChild
        """
        return self._asset_category

    @asset_category.setter
    def asset_category(self, asset_category):
        """Sets the asset_category of this TreeItemAvailableAssetClassResponse.


        :param asset_category: The asset_category of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :type: AssetCategoryChild
        """

        self._asset_category = asset_category

    @property
    def asset_size(self):
        """Gets the asset_size of this TreeItemAvailableAssetClassResponse.  # noqa: E501


        :return: The asset_size of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :rtype: AssetSizeChild
        """
        return self._asset_size

    @asset_size.setter
    def asset_size(self, asset_size):
        """Sets the asset_size of this TreeItemAvailableAssetClassResponse.


        :param asset_size: The asset_size of this TreeItemAvailableAssetClassResponse.  # noqa: E501
        :type: AssetSizeChild
        """

        self._asset_size = asset_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TreeItemAvailableAssetClassResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TreeItemAvailableAssetClassResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.alerts_api import AlertsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestAlertsApi(unittest.TestCase):
    """AlertsApi unit test stubs"""

    def setUp(self):
        self.api = AlertsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acknowledge_alerts(self):
        """Test case for acknowledge_alerts

        Acknowledges all alerts for the supplied groups  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventCategoryChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'int',
        'category_code': 'str',
        'category_name': 'str',
        'category_description': 'str',
        'category_owner_type': 'ActivityEventOwnerType',
        'category_flag': 'ActivityEventCategoryFlag'
    }

    attribute_map = {
        'category_id': 'CategoryId',
        'category_code': 'CategoryCode',
        'category_name': 'CategoryName',
        'category_description': 'CategoryDescription',
        'category_owner_type': 'CategoryOwnerType',
        'category_flag': 'CategoryFlag'
    }

    def __init__(self, category_id=None, category_code=None, category_name=None, category_description=None, category_owner_type=None, category_flag=None):  # noqa: E501
        """ActivityEventCategoryChild - a model defined in Swagger"""  # noqa: E501
        self._category_id = None
        self._category_code = None
        self._category_name = None
        self._category_description = None
        self._category_owner_type = None
        self._category_flag = None
        self.discriminator = None
        if category_id is not None:
            self.category_id = category_id
        if category_code is not None:
            self.category_code = category_code
        if category_name is not None:
            self.category_name = category_name
        if category_description is not None:
            self.category_description = category_description
        if category_owner_type is not None:
            self.category_owner_type = category_owner_type
        if category_flag is not None:
            self.category_flag = category_flag

    @property
    def category_id(self):
        """Gets the category_id of this ActivityEventCategoryChild.  # noqa: E501


        :return: The category_id of this ActivityEventCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this ActivityEventCategoryChild.


        :param category_id: The category_id of this ActivityEventCategoryChild.  # noqa: E501
        :type: int
        """

        self._category_id = category_id

    @property
    def category_code(self):
        """Gets the category_code of this ActivityEventCategoryChild.  # noqa: E501


        :return: The category_code of this ActivityEventCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._category_code

    @category_code.setter
    def category_code(self, category_code):
        """Sets the category_code of this ActivityEventCategoryChild.


        :param category_code: The category_code of this ActivityEventCategoryChild.  # noqa: E501
        :type: str
        """

        self._category_code = category_code

    @property
    def category_name(self):
        """Gets the category_name of this ActivityEventCategoryChild.  # noqa: E501


        :return: The category_name of this ActivityEventCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """Sets the category_name of this ActivityEventCategoryChild.


        :param category_name: The category_name of this ActivityEventCategoryChild.  # noqa: E501
        :type: str
        """

        self._category_name = category_name

    @property
    def category_description(self):
        """Gets the category_description of this ActivityEventCategoryChild.  # noqa: E501


        :return: The category_description of this ActivityEventCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._category_description

    @category_description.setter
    def category_description(self, category_description):
        """Sets the category_description of this ActivityEventCategoryChild.


        :param category_description: The category_description of this ActivityEventCategoryChild.  # noqa: E501
        :type: str
        """

        self._category_description = category_description

    @property
    def category_owner_type(self):
        """Gets the category_owner_type of this ActivityEventCategoryChild.  # noqa: E501


        :return: The category_owner_type of this ActivityEventCategoryChild.  # noqa: E501
        :rtype: ActivityEventOwnerType
        """
        return self._category_owner_type

    @category_owner_type.setter
    def category_owner_type(self, category_owner_type):
        """Sets the category_owner_type of this ActivityEventCategoryChild.


        :param category_owner_type: The category_owner_type of this ActivityEventCategoryChild.  # noqa: E501
        :type: ActivityEventOwnerType
        """

        self._category_owner_type = category_owner_type

    @property
    def category_flag(self):
        """Gets the category_flag of this ActivityEventCategoryChild.  # noqa: E501


        :return: The category_flag of this ActivityEventCategoryChild.  # noqa: E501
        :rtype: ActivityEventCategoryFlag
        """
        return self._category_flag

    @category_flag.setter
    def category_flag(self, category_flag):
        """Sets the category_flag of this ActivityEventCategoryChild.


        :param category_flag: The category_flag of this ActivityEventCategoryChild.  # noqa: E501
        :type: ActivityEventCategoryFlag
        """

        self._category_flag = category_flag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventCategoryChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventCategoryChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetRunningSpeedChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'running_speed_min': 'float',
        'running_speed_max': 'float',
        'running_speed_type': 'AssetRunningSpeedType',
        'running_speed_unit': 'str',
        'running_speed_reference_monitoring_point_id': 'str',
        'running_speed_sensor_role_type': 'SensorRoleTypeCodes',
        'running_speed_harmonic': 'float'
    }

    attribute_map = {
        'running_speed_min': 'RunningSpeedMin',
        'running_speed_max': 'RunningSpeedMax',
        'running_speed_type': 'RunningSpeedType',
        'running_speed_unit': 'RunningSpeedUnit',
        'running_speed_reference_monitoring_point_id': 'RunningSpeedReferenceMonitoringPointId',
        'running_speed_sensor_role_type': 'RunningSpeedSensorRoleType',
        'running_speed_harmonic': 'RunningSpeedHarmonic'
    }

    def __init__(self, running_speed_min=None, running_speed_max=None, running_speed_type=None, running_speed_unit=None, running_speed_reference_monitoring_point_id=None, running_speed_sensor_role_type=None, running_speed_harmonic=None):  # noqa: E501
        """AssetRunningSpeedChild - a model defined in Swagger"""  # noqa: E501
        self._running_speed_min = None
        self._running_speed_max = None
        self._running_speed_type = None
        self._running_speed_unit = None
        self._running_speed_reference_monitoring_point_id = None
        self._running_speed_sensor_role_type = None
        self._running_speed_harmonic = None
        self.discriminator = None
        if running_speed_min is not None:
            self.running_speed_min = running_speed_min
        if running_speed_max is not None:
            self.running_speed_max = running_speed_max
        self.running_speed_type = running_speed_type
        if running_speed_unit is not None:
            self.running_speed_unit = running_speed_unit
        if running_speed_reference_monitoring_point_id is not None:
            self.running_speed_reference_monitoring_point_id = running_speed_reference_monitoring_point_id
        if running_speed_sensor_role_type is not None:
            self.running_speed_sensor_role_type = running_speed_sensor_role_type
        if running_speed_harmonic is not None:
            self.running_speed_harmonic = running_speed_harmonic

    @property
    def running_speed_min(self):
        """Gets the running_speed_min of this AssetRunningSpeedChild.  # noqa: E501

        The minimum running speed in Hz  # noqa: E501

        :return: The running_speed_min of this AssetRunningSpeedChild.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_min

    @running_speed_min.setter
    def running_speed_min(self, running_speed_min):
        """Sets the running_speed_min of this AssetRunningSpeedChild.

        The minimum running speed in Hz  # noqa: E501

        :param running_speed_min: The running_speed_min of this AssetRunningSpeedChild.  # noqa: E501
        :type: float
        """

        self._running_speed_min = running_speed_min

    @property
    def running_speed_max(self):
        """Gets the running_speed_max of this AssetRunningSpeedChild.  # noqa: E501

        The maximum running speed in Hz  # noqa: E501

        :return: The running_speed_max of this AssetRunningSpeedChild.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_max

    @running_speed_max.setter
    def running_speed_max(self, running_speed_max):
        """Sets the running_speed_max of this AssetRunningSpeedChild.

        The maximum running speed in Hz  # noqa: E501

        :param running_speed_max: The running_speed_max of this AssetRunningSpeedChild.  # noqa: E501
        :type: float
        """

        self._running_speed_max = running_speed_max

    @property
    def running_speed_type(self):
        """Gets the running_speed_type of this AssetRunningSpeedChild.  # noqa: E501


        :return: The running_speed_type of this AssetRunningSpeedChild.  # noqa: E501
        :rtype: AssetRunningSpeedType
        """
        return self._running_speed_type

    @running_speed_type.setter
    def running_speed_type(self, running_speed_type):
        """Sets the running_speed_type of this AssetRunningSpeedChild.


        :param running_speed_type: The running_speed_type of this AssetRunningSpeedChild.  # noqa: E501
        :type: AssetRunningSpeedType
        """
        if running_speed_type is None:
            raise ValueError("Invalid value for `running_speed_type`, must not be `None`")  # noqa: E501

        self._running_speed_type = running_speed_type

    @property
    def running_speed_unit(self):
        """Gets the running_speed_unit of this AssetRunningSpeedChild.  # noqa: E501

        The running speed unit: \"CyclesperMin\" | \"Hertz\"  # noqa: E501

        :return: The running_speed_unit of this AssetRunningSpeedChild.  # noqa: E501
        :rtype: str
        """
        return self._running_speed_unit

    @running_speed_unit.setter
    def running_speed_unit(self, running_speed_unit):
        """Sets the running_speed_unit of this AssetRunningSpeedChild.

        The running speed unit: \"CyclesperMin\" | \"Hertz\"  # noqa: E501

        :param running_speed_unit: The running_speed_unit of this AssetRunningSpeedChild.  # noqa: E501
        :type: str
        """

        self._running_speed_unit = running_speed_unit

    @property
    def running_speed_reference_monitoring_point_id(self):
        """Gets the running_speed_reference_monitoring_point_id of this AssetRunningSpeedChild.  # noqa: E501

        The id of the reference monitoring point  # noqa: E501

        :return: The running_speed_reference_monitoring_point_id of this AssetRunningSpeedChild.  # noqa: E501
        :rtype: str
        """
        return self._running_speed_reference_monitoring_point_id

    @running_speed_reference_monitoring_point_id.setter
    def running_speed_reference_monitoring_point_id(self, running_speed_reference_monitoring_point_id):
        """Sets the running_speed_reference_monitoring_point_id of this AssetRunningSpeedChild.

        The id of the reference monitoring point  # noqa: E501

        :param running_speed_reference_monitoring_point_id: The running_speed_reference_monitoring_point_id of this AssetRunningSpeedChild.  # noqa: E501
        :type: str
        """

        self._running_speed_reference_monitoring_point_id = running_speed_reference_monitoring_point_id

    @property
    def running_speed_sensor_role_type(self):
        """Gets the running_speed_sensor_role_type of this AssetRunningSpeedChild.  # noqa: E501


        :return: The running_speed_sensor_role_type of this AssetRunningSpeedChild.  # noqa: E501
        :rtype: SensorRoleTypeCodes
        """
        return self._running_speed_sensor_role_type

    @running_speed_sensor_role_type.setter
    def running_speed_sensor_role_type(self, running_speed_sensor_role_type):
        """Sets the running_speed_sensor_role_type of this AssetRunningSpeedChild.


        :param running_speed_sensor_role_type: The running_speed_sensor_role_type of this AssetRunningSpeedChild.  # noqa: E501
        :type: SensorRoleTypeCodes
        """

        self._running_speed_sensor_role_type = running_speed_sensor_role_type

    @property
    def running_speed_harmonic(self):
        """Gets the running_speed_harmonic of this AssetRunningSpeedChild.  # noqa: E501

        The harmonic value in hz  # noqa: E501

        :return: The running_speed_harmonic of this AssetRunningSpeedChild.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_harmonic

    @running_speed_harmonic.setter
    def running_speed_harmonic(self, running_speed_harmonic):
        """Sets the running_speed_harmonic of this AssetRunningSpeedChild.

        The harmonic value in hz  # noqa: E501

        :param running_speed_harmonic: The running_speed_harmonic of this AssetRunningSpeedChild.  # noqa: E501
        :type: float
        """

        self._running_speed_harmonic = running_speed_harmonic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetRunningSpeedChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetRunningSpeedChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class LocationsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_location(self, **kwargs):  # noqa: E501
        """Creates a new location  # noqa: E501

        Required Permissions: System Admin / Sentry / Corporation Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_location(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LocationCreateRequest body: Model for new location
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_location_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_location_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_location_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a new location  # noqa: E501

        Required Permissions: System Admin / Sentry / Corporation Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_location_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LocationCreateRequest body: Model for new location
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_location" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def generate_location_api_key(self, id, **kwargs):  # noqa: E501
        """Generates a new API key for the specified location, replacing the existing one  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_location_api_key(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generate_location_api_key_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.generate_location_api_key_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def generate_location_api_key_with_http_info(self, id, **kwargs):  # noqa: E501
        """Generates a new API key for the specified location, replacing the existing one  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_location_api_key_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_location_api_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `generate_location_api_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations/{id}/GenerateApiKey', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_baseline_indicators_for_location(self, location_id, **kwargs):  # noqa: E501
        """Gets a list of valid baselines for a given location  # noqa: E501

        Required Permissions: Location User  The searching on this route mimics the original copy baseline functionality from Sd3.  This means the user can choose to narrow down searching on either the group hierarchy, the indicator, or both.  When an asterisk ('*') is included, everything before the asterisk is considered a search on the group hierarchy while  everything after the asterisk will search on the indicator name. Leaving out an asterisk will do a search  on both the indicator name and the group hierarchy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_baseline_indicators_for_location(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: Id of requested location (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `IsDamageAccumulationPressure` | Boolean | `eq, neq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Name`.
        :return: PagedResultsModelIndicatorBaselineResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_baseline_indicators_for_location_with_http_info(location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_baseline_indicators_for_location_with_http_info(location_id, **kwargs)  # noqa: E501
            return data

    def get_baseline_indicators_for_location_with_http_info(self, location_id, **kwargs):  # noqa: E501
        """Gets a list of valid baselines for a given location  # noqa: E501

        Required Permissions: Location User  The searching on this route mimics the original copy baseline functionality from Sd3.  This means the user can choose to narrow down searching on either the group hierarchy, the indicator, or both.  When an asterisk ('*') is included, everything before the asterisk is considered a search on the group hierarchy while  everything after the asterisk will search on the indicator name. Leaving out an asterisk will do a search  on both the indicator name and the group hierarchy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_baseline_indicators_for_location_with_http_info(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: Id of requested location (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `IsDamageAccumulationPressure` | Boolean | `eq, neq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Name`.
        :return: PagedResultsModelIndicatorBaselineResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_id', 'filter', 'page', 'page_limit', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_baseline_indicators_for_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `get_baseline_indicators_for_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations/{locationId}/indicators/baselines', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelIndicatorBaselineResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_location(self, location_id, **kwargs):  # noqa: E501
        """Gets a specific location  # noqa: E501

        Required Permissions: Users, Sentry, and System Admins will receive all the locations that are visible to them at their access level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_location(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: Id of location (required)
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_location_with_http_info(location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_location_with_http_info(location_id, **kwargs)  # noqa: E501
            return data

    def get_location_with_http_info(self, location_id, **kwargs):  # noqa: E501
        """Gets a specific location  # noqa: E501

        Required Permissions: Users, Sentry, and System Admins will receive all the locations that are visible to them at their access level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_location_with_http_info(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: Id of location (required)
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `get_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations/{locationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_location_roi(self, location_id, **kwargs):  # noqa: E501
        """Gets ROI information for a location  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_location_roi(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: (required)
        :param datetime start_date:
        :param datetime end_date:
        :return: RoiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_location_roi_with_http_info(location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_location_roi_with_http_info(location_id, **kwargs)  # noqa: E501
            return data

    def get_location_roi_with_http_info(self, location_id, **kwargs):  # noqa: E501
        """Gets ROI information for a location  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_location_roi_with_http_info(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: (required)
        :param datetime start_date:
        :param datetime end_date:
        :return: RoiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_id', 'start_date', 'end_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_location_roi" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `get_location_roi`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []
        if 'start_date' in params:
            query_params.append(('StartDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('EndDate', params['end_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations/{locationId}/roi', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RoiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_locations(self, **kwargs):  # noqa: E501
        """Returns a paged list of all locations that the user has access to  # noqa: E501

        Required Permissions: Users, Sentry, and System Admins will receive all the locations that are visible to them at their access level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_locations(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, like, in` | | `Active` | Boolean | `eq, neq` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Id` | Guid | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `Active` | Boolean | | `CorporationName` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `CorporationName`, `Name`.
        :return: PagedResultsModelLocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_locations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_locations_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_locations_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a paged list of all locations that the user has access to  # noqa: E501

        Required Permissions: Users, Sentry, and System Admins will receive all the locations that are visible to them at their access level.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_locations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, like, in` | | `Active` | Boolean | `eq, neq` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Id` | Guid | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `Active` | Boolean | | `CorporationName` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `CorporationName`, `Name`.
        :return: PagedResultsModelLocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_locations" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelLocationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_location(self, id, **kwargs):  # noqa: E501
        """Updates the specified location  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_location(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param LocationUpdateRequest body: Model for updated location
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_location_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_location_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_location_with_http_info(self, id, **kwargs):  # noqa: E501
        """Updates the specified location  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_location_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param LocationUpdateRequest body: Model for updated location
        :return: LocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_location_permissions(self, id, **kwargs):  # noqa: E501
        """Updates the feature-permissions for the specified location  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_location_permissions(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param LocationPermissionsUpdateRequest body: Model for updated location permissions
        :return: LocationPermissionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_location_permissions_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_location_permissions_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_location_permissions_with_http_info(self, id, **kwargs):  # noqa: E501
        """Updates the feature-permissions for the specified location  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_location_permissions_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param LocationPermissionsUpdateRequest body: Model for updated location permissions
        :return: LocationPermissionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_location_permissions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_location_permissions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Locations/{id}/Permissions', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LocationPermissionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MonitoringPointCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'abbreviation': 'str',
        'parent_id': 'str',
        'bearing_id': 'str',
        'monitoring_point_type_code': 'MonitoringPointTypeCodesForApi',
        'running_speed_multiplier': 'float',
        'note': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'parent_id': 'ParentId',
        'bearing_id': 'BearingId',
        'monitoring_point_type_code': 'MonitoringPointTypeCode',
        'running_speed_multiplier': 'RunningSpeedMultiplier',
        'note': 'Note'
    }

    def __init__(self, name=None, abbreviation=None, parent_id=None, bearing_id=None, monitoring_point_type_code=None, running_speed_multiplier=1, note=None):  # noqa: E501
        """MonitoringPointCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._abbreviation = None
        self._parent_id = None
        self._bearing_id = None
        self._monitoring_point_type_code = None
        self._running_speed_multiplier = None
        self._note = None
        self.discriminator = None
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.parent_id = parent_id
        if bearing_id is not None:
            self.bearing_id = bearing_id
        self.monitoring_point_type_code = monitoring_point_type_code
        if running_speed_multiplier is not None:
            self.running_speed_multiplier = running_speed_multiplier
        if note is not None:
            self.note = note

    @property
    def name(self):
        """Gets the name of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The name of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MonitoringPointCreateRequest.


        :param name: The name of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The abbreviation of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this MonitoringPointCreateRequest.


        :param abbreviation: The abbreviation of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def parent_id(self):
        """Gets the parent_id of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The parent_id of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this MonitoringPointCreateRequest.


        :param parent_id: The parent_id of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """
        if parent_id is None:
            raise ValueError("Invalid value for `parent_id`, must not be `None`")  # noqa: E501

        self._parent_id = parent_id

    @property
    def bearing_id(self):
        """Gets the bearing_id of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The bearing_id of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._bearing_id

    @bearing_id.setter
    def bearing_id(self, bearing_id):
        """Sets the bearing_id of this MonitoringPointCreateRequest.


        :param bearing_id: The bearing_id of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """

        self._bearing_id = bearing_id

    @property
    def monitoring_point_type_code(self):
        """Gets the monitoring_point_type_code of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The monitoring_point_type_code of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: MonitoringPointTypeCodesForApi
        """
        return self._monitoring_point_type_code

    @monitoring_point_type_code.setter
    def monitoring_point_type_code(self, monitoring_point_type_code):
        """Sets the monitoring_point_type_code of this MonitoringPointCreateRequest.


        :param monitoring_point_type_code: The monitoring_point_type_code of this MonitoringPointCreateRequest.  # noqa: E501
        :type: MonitoringPointTypeCodesForApi
        """
        if monitoring_point_type_code is None:
            raise ValueError("Invalid value for `monitoring_point_type_code`, must not be `None`")  # noqa: E501

        self._monitoring_point_type_code = monitoring_point_type_code

    @property
    def running_speed_multiplier(self):
        """Gets the running_speed_multiplier of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The running_speed_multiplier of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_multiplier

    @running_speed_multiplier.setter
    def running_speed_multiplier(self, running_speed_multiplier):
        """Sets the running_speed_multiplier of this MonitoringPointCreateRequest.


        :param running_speed_multiplier: The running_speed_multiplier of this MonitoringPointCreateRequest.  # noqa: E501
        :type: float
        """

        self._running_speed_multiplier = running_speed_multiplier

    @property
    def note(self):
        """Gets the note of this MonitoringPointCreateRequest.  # noqa: E501


        :return: The note of this MonitoringPointCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this MonitoringPointCreateRequest.


        :param note: The note of this MonitoringPointCreateRequest.  # noqa: E501
        :type: str
        """

        self._note = note

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitoringPointCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitoringPointCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MonitoringPointAssignmentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'is_paused': 'bool',
        'monitoring_point': 'MonitoringPointChild',
        'node': 'MonitoringPointNodeChild',
        'corporation': 'CorporationChild',
        'location': 'LocationChild'
    }

    attribute_map = {
        'id': 'Id',
        'start_date': 'StartDate',
        'end_date': 'EndDate',
        'is_paused': 'IsPaused',
        'monitoring_point': 'MonitoringPoint',
        'node': 'Node',
        'corporation': 'Corporation',
        'location': 'Location'
    }

    def __init__(self, id=None, start_date=None, end_date=None, is_paused=None, monitoring_point=None, node=None, corporation=None, location=None):  # noqa: E501
        """MonitoringPointAssignmentResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._start_date = None
        self._end_date = None
        self._is_paused = None
        self._monitoring_point = None
        self._node = None
        self._corporation = None
        self._location = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if is_paused is not None:
            self.is_paused = is_paused
        if monitoring_point is not None:
            self.monitoring_point = monitoring_point
        if node is not None:
            self.node = node
        if corporation is not None:
            self.corporation = corporation
        if location is not None:
            self.location = location

    @property
    def id(self):
        """Gets the id of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The id of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MonitoringPointAssignmentResponse.


        :param id: The id of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def start_date(self):
        """Gets the start_date of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The start_date of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this MonitoringPointAssignmentResponse.


        :param start_date: The start_date of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The end_date of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this MonitoringPointAssignmentResponse.


        :param end_date: The end_date of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def is_paused(self):
        """Gets the is_paused of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The is_paused of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this MonitoringPointAssignmentResponse.


        :param is_paused: The is_paused of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: bool
        """

        self._is_paused = is_paused

    @property
    def monitoring_point(self):
        """Gets the monitoring_point of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The monitoring_point of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: MonitoringPointChild
        """
        return self._monitoring_point

    @monitoring_point.setter
    def monitoring_point(self, monitoring_point):
        """Sets the monitoring_point of this MonitoringPointAssignmentResponse.


        :param monitoring_point: The monitoring_point of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: MonitoringPointChild
        """

        self._monitoring_point = monitoring_point

    @property
    def node(self):
        """Gets the node of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The node of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: MonitoringPointNodeChild
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this MonitoringPointAssignmentResponse.


        :param node: The node of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: MonitoringPointNodeChild
        """

        self._node = node

    @property
    def corporation(self):
        """Gets the corporation of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The corporation of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this MonitoringPointAssignmentResponse.


        :param corporation: The corporation of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: CorporationChild
        """

        self._corporation = corporation

    @property
    def location(self):
        """Gets the location of this MonitoringPointAssignmentResponse.  # noqa: E501


        :return: The location of this MonitoringPointAssignmentResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this MonitoringPointAssignmentResponse.


        :param location: The location of this MonitoringPointAssignmentResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitoringPointAssignmentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitoringPointAssignmentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReceiverChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'receiver_id': 'int',
        'receiver_serial_number': 'str',
        'receiver_name': 'str',
        'receiver_firmware_version': 'str',
        'receiver_network_id': 'str',
        'receiver_rf_channel': 'int',
        'receiver_pending_rf_channel': 'int'
    }

    attribute_map = {
        'receiver_id': 'ReceiverId',
        'receiver_serial_number': 'ReceiverSerialNumber',
        'receiver_name': 'ReceiverName',
        'receiver_firmware_version': 'ReceiverFirmwareVersion',
        'receiver_network_id': 'ReceiverNetworkId',
        'receiver_rf_channel': 'ReceiverRfChannel',
        'receiver_pending_rf_channel': 'ReceiverPendingRfChannel'
    }

    def __init__(self, receiver_id=None, receiver_serial_number=None, receiver_name=None, receiver_firmware_version=None, receiver_network_id=None, receiver_rf_channel=None, receiver_pending_rf_channel=None):  # noqa: E501
        """ReceiverChild - a model defined in Swagger"""  # noqa: E501
        self._receiver_id = None
        self._receiver_serial_number = None
        self._receiver_name = None
        self._receiver_firmware_version = None
        self._receiver_network_id = None
        self._receiver_rf_channel = None
        self._receiver_pending_rf_channel = None
        self.discriminator = None
        self.receiver_id = receiver_id
        self.receiver_serial_number = receiver_serial_number
        if receiver_name is not None:
            self.receiver_name = receiver_name
        if receiver_firmware_version is not None:
            self.receiver_firmware_version = receiver_firmware_version
        if receiver_network_id is not None:
            self.receiver_network_id = receiver_network_id
        if receiver_rf_channel is not None:
            self.receiver_rf_channel = receiver_rf_channel
        if receiver_pending_rf_channel is not None:
            self.receiver_pending_rf_channel = receiver_pending_rf_channel

    @property
    def receiver_id(self):
        """Gets the receiver_id of this ReceiverChild.  # noqa: E501


        :return: The receiver_id of this ReceiverChild.  # noqa: E501
        :rtype: int
        """
        return self._receiver_id

    @receiver_id.setter
    def receiver_id(self, receiver_id):
        """Sets the receiver_id of this ReceiverChild.


        :param receiver_id: The receiver_id of this ReceiverChild.  # noqa: E501
        :type: int
        """
        if receiver_id is None:
            raise ValueError("Invalid value for `receiver_id`, must not be `None`")  # noqa: E501

        self._receiver_id = receiver_id

    @property
    def receiver_serial_number(self):
        """Gets the receiver_serial_number of this ReceiverChild.  # noqa: E501


        :return: The receiver_serial_number of this ReceiverChild.  # noqa: E501
        :rtype: str
        """
        return self._receiver_serial_number

    @receiver_serial_number.setter
    def receiver_serial_number(self, receiver_serial_number):
        """Sets the receiver_serial_number of this ReceiverChild.


        :param receiver_serial_number: The receiver_serial_number of this ReceiverChild.  # noqa: E501
        :type: str
        """
        if receiver_serial_number is None:
            raise ValueError("Invalid value for `receiver_serial_number`, must not be `None`")  # noqa: E501

        self._receiver_serial_number = receiver_serial_number

    @property
    def receiver_name(self):
        """Gets the receiver_name of this ReceiverChild.  # noqa: E501


        :return: The receiver_name of this ReceiverChild.  # noqa: E501
        :rtype: str
        """
        return self._receiver_name

    @receiver_name.setter
    def receiver_name(self, receiver_name):
        """Sets the receiver_name of this ReceiverChild.


        :param receiver_name: The receiver_name of this ReceiverChild.  # noqa: E501
        :type: str
        """

        self._receiver_name = receiver_name

    @property
    def receiver_firmware_version(self):
        """Gets the receiver_firmware_version of this ReceiverChild.  # noqa: E501


        :return: The receiver_firmware_version of this ReceiverChild.  # noqa: E501
        :rtype: str
        """
        return self._receiver_firmware_version

    @receiver_firmware_version.setter
    def receiver_firmware_version(self, receiver_firmware_version):
        """Sets the receiver_firmware_version of this ReceiverChild.


        :param receiver_firmware_version: The receiver_firmware_version of this ReceiverChild.  # noqa: E501
        :type: str
        """

        self._receiver_firmware_version = receiver_firmware_version

    @property
    def receiver_network_id(self):
        """Gets the receiver_network_id of this ReceiverChild.  # noqa: E501


        :return: The receiver_network_id of this ReceiverChild.  # noqa: E501
        :rtype: str
        """
        return self._receiver_network_id

    @receiver_network_id.setter
    def receiver_network_id(self, receiver_network_id):
        """Sets the receiver_network_id of this ReceiverChild.


        :param receiver_network_id: The receiver_network_id of this ReceiverChild.  # noqa: E501
        :type: str
        """

        self._receiver_network_id = receiver_network_id

    @property
    def receiver_rf_channel(self):
        """Gets the receiver_rf_channel of this ReceiverChild.  # noqa: E501


        :return: The receiver_rf_channel of this ReceiverChild.  # noqa: E501
        :rtype: int
        """
        return self._receiver_rf_channel

    @receiver_rf_channel.setter
    def receiver_rf_channel(self, receiver_rf_channel):
        """Sets the receiver_rf_channel of this ReceiverChild.


        :param receiver_rf_channel: The receiver_rf_channel of this ReceiverChild.  # noqa: E501
        :type: int
        """

        self._receiver_rf_channel = receiver_rf_channel

    @property
    def receiver_pending_rf_channel(self):
        """Gets the receiver_pending_rf_channel of this ReceiverChild.  # noqa: E501


        :return: The receiver_pending_rf_channel of this ReceiverChild.  # noqa: E501
        :rtype: int
        """
        return self._receiver_pending_rf_channel

    @receiver_pending_rf_channel.setter
    def receiver_pending_rf_channel(self, receiver_pending_rf_channel):
        """Sets the receiver_pending_rf_channel of this ReceiverChild.


        :param receiver_pending_rf_channel: The receiver_pending_rf_channel of this ReceiverChild.  # noqa: E501
        :type: int
        """

        self._receiver_pending_rf_channel = receiver_pending_rf_channel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReceiverChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReceiverChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.locations_api import LocationsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestLocationsApi(unittest.TestCase):
    """LocationsApi unit test stubs"""

    def setUp(self):
        self.api = LocationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_location(self):
        """Test case for create_location

        Creates a new location  # noqa: E501
        """
        pass

    def test_generate_location_api_key(self):
        """Test case for generate_location_api_key

        Generates a new API key for the specified location, replacing the existing one  # noqa: E501
        """
        pass

    def test_get_baseline_indicators_for_location(self):
        """Test case for get_baseline_indicators_for_location

        Gets a list of valid baselines for a given location  # noqa: E501
        """
        pass

    def test_get_location(self):
        """Test case for get_location

        Gets a specific location  # noqa: E501
        """
        pass

    def test_get_location_roi(self):
        """Test case for get_location_roi

        Gets ROI information for a location  # noqa: E501
        """
        pass

    def test_get_locations(self):
        """Test case for get_locations

        Returns a paged list of all locations that the user has access to  # noqa: E501
        """
        pass

    def test_update_location(self):
        """Test case for update_location

        Updates the specified location  # noqa: E501
        """
        pass

    def test_update_location_permissions(self):
        """Test case for update_location_permissions

        Updates the feature-permissions for the specified location  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from smart_diagnostics_client.api.activity_events_api import ActivityEventsApi
from smart_diagnostics_client.api.alerts_api import AlertsApi
from smart_diagnostics_client.api.analytics_api import AnalyticsApi
from smart_diagnostics_client.api.assets_api import AssetsApi
from smart_diagnostics_client.api.base_stations_api import BaseStationsApi
from smart_diagnostics_client.api.bearings_api import BearingsApi
from smart_diagnostics_client.api.board_ticket_statuses_api import BoardTicketStatusesApi
from smart_diagnostics_client.api.board_tickets_api import BoardTicketsApi
from smart_diagnostics_client.api.bulletins_api import BulletinsApi
from smart_diagnostics_client.api.corporations_api import CorporationsApi
from smart_diagnostics_client.api.dashboards_api import DashboardsApi
from smart_diagnostics_client.api.documents_api import DocumentsApi
from smart_diagnostics_client.api.events_api import EventsApi
from smart_diagnostics_client.api.files_api import FilesApi
from smart_diagnostics_client.api.filters_api import FiltersApi
from smart_diagnostics_client.api.groups_api import GroupsApi
from smart_diagnostics_client.api.hardware_events_api import HardwareEventsApi
from smart_diagnostics_client.api.hardware_status_api import HardwareStatusApi
from smart_diagnostics_client.api.hubs_api import HubsApi
from smart_diagnostics_client.api.identity_providers_api import IdentityProvidersApi
from smart_diagnostics_client.api.indicator_groups_api import IndicatorGroupsApi
from smart_diagnostics_client.api.indicators_api import IndicatorsApi
from smart_diagnostics_client.api.installs_api import InstallsApi
from smart_diagnostics_client.api.locations_api import LocationsApi
from smart_diagnostics_client.api.markers_api import MarkersApi
from smart_diagnostics_client.api.monitoring_point_type_codes_api import MonitoringPointTypeCodesApi
from smart_diagnostics_client.api.monitoring_points_api import MonitoringPointsApi
from smart_diagnostics_client.api.nodes_api import NodesApi
from smart_diagnostics_client.api.pictures_api import PicturesApi
from smart_diagnostics_client.api.properties_api import PropertiesApi
from smart_diagnostics_client.api.receivers_api import ReceiversApi
from smart_diagnostics_client.api.repeaters_api import RepeatersApi
from smart_diagnostics_client.api.reports_api import ReportsApi
from smart_diagnostics_client.api.sensors_api import SensorsApi
from smart_diagnostics_client.api.sessions_api import SessionsApi
from smart_diagnostics_client.api.setup_tools_api import SetupToolsApi
from smart_diagnostics_client.api.sub_systems_api import SubSystemsApi
from smart_diagnostics_client.api.systems_api import SystemsApi
from smart_diagnostics_client.api.tags_api import TagsApi
from smart_diagnostics_client.api.thermal_cameras_api import ThermalCamerasApi
from smart_diagnostics_client.api.tokens_api import TokensApi
from smart_diagnostics_client.api.tree_items_api import TreeItemsApi
from smart_diagnostics_client.api.user_permission_api import UserPermissionApi
from smart_diagnostics_client.api.users_api import UsersApi



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ThermalCameraRegionResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'instance': 'int',
        'x_coordinate': 'int',
        'y_coordinate': 'int',
        'width': 'int',
        'height': 'int',
        'created': 'datetime',
        'updated': 'datetime',
        'active': 'bool',
        'thermal_camera_serial_number': 'int',
        'location': 'ThermalCameraRegionLocationChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'instance': 'Instance',
        'x_coordinate': 'XCoordinate',
        'y_coordinate': 'YCoordinate',
        'width': 'Width',
        'height': 'Height',
        'created': 'Created',
        'updated': 'Updated',
        'active': 'Active',
        'thermal_camera_serial_number': 'ThermalCameraSerialNumber',
        'location': 'Location'
    }

    def __init__(self, id=None, name=None, instance=None, x_coordinate=None, y_coordinate=None, width=None, height=None, created=None, updated=None, active=None, thermal_camera_serial_number=None, location=None):  # noqa: E501
        """ThermalCameraRegionResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._instance = None
        self._x_coordinate = None
        self._y_coordinate = None
        self._width = None
        self._height = None
        self._created = None
        self._updated = None
        self._active = None
        self._thermal_camera_serial_number = None
        self._location = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.instance = instance
        self.x_coordinate = x_coordinate
        self.y_coordinate = y_coordinate
        self.width = width
        self.height = height
        self.created = created
        self.updated = updated
        self.active = active
        self.thermal_camera_serial_number = thermal_camera_serial_number
        self.location = location

    @property
    def id(self):
        """Gets the id of this ThermalCameraRegionResponse.  # noqa: E501

        The ID for the region  # noqa: E501

        :return: The id of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ThermalCameraRegionResponse.

        The ID for the region  # noqa: E501

        :param id: The id of this ThermalCameraRegionResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this ThermalCameraRegionResponse.  # noqa: E501

        The name of the region  # noqa: E501

        :return: The name of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ThermalCameraRegionResponse.

        The name of the region  # noqa: E501

        :param name: The name of this ThermalCameraRegionResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def instance(self):
        """Gets the instance of this ThermalCameraRegionResponse.  # noqa: E501

        The unique set of coordinates that designates a region.  # noqa: E501

        :return: The instance of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: int
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this ThermalCameraRegionResponse.

        The unique set of coordinates that designates a region.  # noqa: E501

        :param instance: The instance of this ThermalCameraRegionResponse.  # noqa: E501
        :type: int
        """
        if instance is None:
            raise ValueError("Invalid value for `instance`, must not be `None`")  # noqa: E501

        self._instance = instance

    @property
    def x_coordinate(self):
        """Gets the x_coordinate of this ThermalCameraRegionResponse.  # noqa: E501

        The \"X\" coordinate that determines the position of the region.  In other words, where the region is located.  # noqa: E501

        :return: The x_coordinate of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: int
        """
        return self._x_coordinate

    @x_coordinate.setter
    def x_coordinate(self, x_coordinate):
        """Sets the x_coordinate of this ThermalCameraRegionResponse.

        The \"X\" coordinate that determines the position of the region.  In other words, where the region is located.  # noqa: E501

        :param x_coordinate: The x_coordinate of this ThermalCameraRegionResponse.  # noqa: E501
        :type: int
        """
        if x_coordinate is None:
            raise ValueError("Invalid value for `x_coordinate`, must not be `None`")  # noqa: E501

        self._x_coordinate = x_coordinate

    @property
    def y_coordinate(self):
        """Gets the y_coordinate of this ThermalCameraRegionResponse.  # noqa: E501

        The \"Y\" coordinate that determines the position of the region.  In other words, where the region is located.  # noqa: E501

        :return: The y_coordinate of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: int
        """
        return self._y_coordinate

    @y_coordinate.setter
    def y_coordinate(self, y_coordinate):
        """Sets the y_coordinate of this ThermalCameraRegionResponse.

        The \"Y\" coordinate that determines the position of the region.  In other words, where the region is located.  # noqa: E501

        :param y_coordinate: The y_coordinate of this ThermalCameraRegionResponse.  # noqa: E501
        :type: int
        """
        if y_coordinate is None:
            raise ValueError("Invalid value for `y_coordinate`, must not be `None`")  # noqa: E501

        self._y_coordinate = y_coordinate

    @property
    def width(self):
        """Gets the width of this ThermalCameraRegionResponse.  # noqa: E501

        The width of the region  # noqa: E501

        :return: The width of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this ThermalCameraRegionResponse.

        The width of the region  # noqa: E501

        :param width: The width of this ThermalCameraRegionResponse.  # noqa: E501
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501

        self._width = width

    @property
    def height(self):
        """Gets the height of this ThermalCameraRegionResponse.  # noqa: E501

        The height of the region  # noqa: E501

        :return: The height of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this ThermalCameraRegionResponse.

        The height of the region  # noqa: E501

        :param height: The height of this ThermalCameraRegionResponse.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    @property
    def created(self):
        """Gets the created of this ThermalCameraRegionResponse.  # noqa: E501

        The Date the thermal region was originally created  # noqa: E501

        :return: The created of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ThermalCameraRegionResponse.

        The Date the thermal region was originally created  # noqa: E501

        :param created: The created of this ThermalCameraRegionResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this ThermalCameraRegionResponse.  # noqa: E501

        Represents the last time the region had properties that were updated  # noqa: E501

        :return: The updated of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ThermalCameraRegionResponse.

        Represents the last time the region had properties that were updated  # noqa: E501

        :param updated: The updated of this ThermalCameraRegionResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def active(self):
        """Gets the active of this ThermalCameraRegionResponse.  # noqa: E501

        Whether or not the thermal region is currently active  # noqa: E501

        :return: The active of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this ThermalCameraRegionResponse.

        Whether or not the thermal region is currently active  # noqa: E501

        :param active: The active of this ThermalCameraRegionResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def thermal_camera_serial_number(self):
        """Gets the thermal_camera_serial_number of this ThermalCameraRegionResponse.  # noqa: E501

        The serial number for the Thermal Camera the region belongs to  # noqa: E501

        :return: The thermal_camera_serial_number of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: int
        """
        return self._thermal_camera_serial_number

    @thermal_camera_serial_number.setter
    def thermal_camera_serial_number(self, thermal_camera_serial_number):
        """Sets the thermal_camera_serial_number of this ThermalCameraRegionResponse.

        The serial number for the Thermal Camera the region belongs to  # noqa: E501

        :param thermal_camera_serial_number: The thermal_camera_serial_number of this ThermalCameraRegionResponse.  # noqa: E501
        :type: int
        """
        if thermal_camera_serial_number is None:
            raise ValueError("Invalid value for `thermal_camera_serial_number`, must not be `None`")  # noqa: E501

        self._thermal_camera_serial_number = thermal_camera_serial_number

    @property
    def location(self):
        """Gets the location of this ThermalCameraRegionResponse.  # noqa: E501


        :return: The location of this ThermalCameraRegionResponse.  # noqa: E501
        :rtype: ThermalCameraRegionLocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ThermalCameraRegionResponse.


        :param location: The location of this ThermalCameraRegionResponse.  # noqa: E501
        :type: ThermalCameraRegionLocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ThermalCameraRegionResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThermalCameraRegionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.bulletins_api import BulletinsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBulletinsApi(unittest.TestCase):
    """BulletinsApi unit test stubs"""

    def setUp(self):
        self.api = BulletinsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bulletin(self):
        """Test case for create_bulletin

        Creates a bulletin  # noqa: E501
        """
        pass

    def test_delete_bulletin(self):
        """Test case for delete_bulletin

        Deletes a bulletin  # noqa: E501
        """
        pass

    def test_get_bulletin(self):
        """Test case for get_bulletin

        Gets a specific bulletin  # noqa: E501
        """
        pass

    def test_get_bulletins(self):
        """Test case for get_bulletins

        Gets bulletins  # noqa: E501
        """
        pass

    def test_update_bulletin(self):
        """Test case for update_bulletin

        Updates a bulletin  # noqa: E501
        """
        pass

    def test_update_bulletin_image(self):
        """Test case for update_bulletin_image

        Updates a bulletin's image  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ThermalCameraSettingsUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'atmosphere_temperature': 'float',
        'emissivity': 'float',
        'distance': 'float',
        'reflected_temperature': 'float',
        'relative_humidity': 'float',
        'window_transmission_rate': 'float',
        'window_temperature': 'float',
        'update_interval': 'int'
    }

    attribute_map = {
        'atmosphere_temperature': 'AtmosphereTemperature',
        'emissivity': 'Emissivity',
        'distance': 'Distance',
        'reflected_temperature': 'ReflectedTemperature',
        'relative_humidity': 'RelativeHumidity',
        'window_transmission_rate': 'WindowTransmissionRate',
        'window_temperature': 'WindowTemperature',
        'update_interval': 'UpdateInterval'
    }

    def __init__(self, atmosphere_temperature=None, emissivity=None, distance=None, reflected_temperature=None, relative_humidity=None, window_transmission_rate=None, window_temperature=None, update_interval=None):  # noqa: E501
        """ThermalCameraSettingsUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._atmosphere_temperature = None
        self._emissivity = None
        self._distance = None
        self._reflected_temperature = None
        self._relative_humidity = None
        self._window_transmission_rate = None
        self._window_temperature = None
        self._update_interval = None
        self.discriminator = None
        self.atmosphere_temperature = atmosphere_temperature
        self.emissivity = emissivity
        self.distance = distance
        self.reflected_temperature = reflected_temperature
        self.relative_humidity = relative_humidity
        self.window_transmission_rate = window_transmission_rate
        self.window_temperature = window_temperature
        self.update_interval = update_interval

    @property
    def atmosphere_temperature(self):
        """Gets the atmosphere_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        The ambient temperature on the camera in Kelvin.  # noqa: E501

        :return: The atmosphere_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._atmosphere_temperature

    @atmosphere_temperature.setter
    def atmosphere_temperature(self, atmosphere_temperature):
        """Sets the atmosphere_temperature of this ThermalCameraSettingsUpdateRequest.

        The ambient temperature on the camera in Kelvin.  # noqa: E501

        :param atmosphere_temperature: The atmosphere_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: float
        """
        if atmosphere_temperature is None:
            raise ValueError("Invalid value for `atmosphere_temperature`, must not be `None`")  # noqa: E501

        self._atmosphere_temperature = atmosphere_temperature

    @property
    def emissivity(self):
        """Gets the emissivity of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        The Emissivity value used in calculating temperature.  # noqa: E501

        :return: The emissivity of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._emissivity

    @emissivity.setter
    def emissivity(self, emissivity):
        """Sets the emissivity of this ThermalCameraSettingsUpdateRequest.

        The Emissivity value used in calculating temperature.  # noqa: E501

        :param emissivity: The emissivity of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: float
        """
        if emissivity is None:
            raise ValueError("Invalid value for `emissivity`, must not be `None`")  # noqa: E501

        self._emissivity = emissivity

    @property
    def distance(self):
        """Gets the distance of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        The distance in meters between the camera and the object being measured.  # noqa: E501

        :return: The distance of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this ThermalCameraSettingsUpdateRequest.

        The distance in meters between the camera and the object being measured.  # noqa: E501

        :param distance: The distance of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: float
        """
        if distance is None:
            raise ValueError("Invalid value for `distance`, must not be `None`")  # noqa: E501

        self._distance = distance

    @property
    def reflected_temperature(self):
        """Gets the reflected_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        The reflected temperature of the object in Kelvin.  # noqa: E501

        :return: The reflected_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._reflected_temperature

    @reflected_temperature.setter
    def reflected_temperature(self, reflected_temperature):
        """Sets the reflected_temperature of this ThermalCameraSettingsUpdateRequest.

        The reflected temperature of the object in Kelvin.  # noqa: E501

        :param reflected_temperature: The reflected_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: float
        """
        if reflected_temperature is None:
            raise ValueError("Invalid value for `reflected_temperature`, must not be `None`")  # noqa: E501

        self._reflected_temperature = reflected_temperature

    @property
    def relative_humidity(self):
        """Gets the relative_humidity of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        The relative humidity of the camera.  # noqa: E501

        :return: The relative_humidity of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._relative_humidity

    @relative_humidity.setter
    def relative_humidity(self, relative_humidity):
        """Sets the relative_humidity of this ThermalCameraSettingsUpdateRequest.

        The relative humidity of the camera.  # noqa: E501

        :param relative_humidity: The relative_humidity of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: float
        """
        if relative_humidity is None:
            raise ValueError("Invalid value for `relative_humidity`, must not be `None`")  # noqa: E501

        self._relative_humidity = relative_humidity

    @property
    def window_transmission_rate(self):
        """Gets the window_transmission_rate of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        The amount of thermal radiation allowed through an external window.  # noqa: E501

        :return: The window_transmission_rate of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._window_transmission_rate

    @window_transmission_rate.setter
    def window_transmission_rate(self, window_transmission_rate):
        """Sets the window_transmission_rate of this ThermalCameraSettingsUpdateRequest.

        The amount of thermal radiation allowed through an external window.  # noqa: E501

        :param window_transmission_rate: The window_transmission_rate of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: float
        """
        if window_transmission_rate is None:
            raise ValueError("Invalid value for `window_transmission_rate`, must not be `None`")  # noqa: E501

        self._window_transmission_rate = window_transmission_rate

    @property
    def window_temperature(self):
        """Gets the window_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        The temperature of any external thermal windows in Kelvin.  # noqa: E501

        :return: The window_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._window_temperature

    @window_temperature.setter
    def window_temperature(self, window_temperature):
        """Sets the window_temperature of this ThermalCameraSettingsUpdateRequest.

        The temperature of any external thermal windows in Kelvin.  # noqa: E501

        :param window_temperature: The window_temperature of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: float
        """
        if window_temperature is None:
            raise ValueError("Invalid value for `window_temperature`, must not be `None`")  # noqa: E501

        self._window_temperature = window_temperature

    @property
    def update_interval(self):
        """Gets the update_interval of this ThermalCameraSettingsUpdateRequest.  # noqa: E501

        How often a value is transmitted to SD  # noqa: E501

        :return: The update_interval of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._update_interval

    @update_interval.setter
    def update_interval(self, update_interval):
        """Sets the update_interval of this ThermalCameraSettingsUpdateRequest.

        How often a value is transmitted to SD  # noqa: E501

        :param update_interval: The update_interval of this ThermalCameraSettingsUpdateRequest.  # noqa: E501
        :type: int
        """
        if update_interval is None:
            raise ValueError("Invalid value for `update_interval`, must not be `None`")  # noqa: E501

        self._update_interval = update_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ThermalCameraSettingsUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThermalCameraSettingsUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MarkerChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'marker_name': 'str',
        'marker_show_harmonics': 'bool',
        'marker_show_side_bands': 'bool',
        'marker_show_peaks': 'bool'
    }

    attribute_map = {
        'marker_name': 'MarkerName',
        'marker_show_harmonics': 'MarkerShowHarmonics',
        'marker_show_side_bands': 'MarkerShowSideBands',
        'marker_show_peaks': 'MarkerShowPeaks'
    }

    def __init__(self, marker_name=None, marker_show_harmonics=None, marker_show_side_bands=None, marker_show_peaks=None):  # noqa: E501
        """MarkerChild - a model defined in Swagger"""  # noqa: E501
        self._marker_name = None
        self._marker_show_harmonics = None
        self._marker_show_side_bands = None
        self._marker_show_peaks = None
        self.discriminator = None
        if marker_name is not None:
            self.marker_name = marker_name
        self.marker_show_harmonics = marker_show_harmonics
        self.marker_show_side_bands = marker_show_side_bands
        self.marker_show_peaks = marker_show_peaks

    @property
    def marker_name(self):
        """Gets the marker_name of this MarkerChild.  # noqa: E501


        :return: The marker_name of this MarkerChild.  # noqa: E501
        :rtype: str
        """
        return self._marker_name

    @marker_name.setter
    def marker_name(self, marker_name):
        """Sets the marker_name of this MarkerChild.


        :param marker_name: The marker_name of this MarkerChild.  # noqa: E501
        :type: str
        """

        self._marker_name = marker_name

    @property
    def marker_show_harmonics(self):
        """Gets the marker_show_harmonics of this MarkerChild.  # noqa: E501


        :return: The marker_show_harmonics of this MarkerChild.  # noqa: E501
        :rtype: bool
        """
        return self._marker_show_harmonics

    @marker_show_harmonics.setter
    def marker_show_harmonics(self, marker_show_harmonics):
        """Sets the marker_show_harmonics of this MarkerChild.


        :param marker_show_harmonics: The marker_show_harmonics of this MarkerChild.  # noqa: E501
        :type: bool
        """
        if marker_show_harmonics is None:
            raise ValueError("Invalid value for `marker_show_harmonics`, must not be `None`")  # noqa: E501

        self._marker_show_harmonics = marker_show_harmonics

    @property
    def marker_show_side_bands(self):
        """Gets the marker_show_side_bands of this MarkerChild.  # noqa: E501


        :return: The marker_show_side_bands of this MarkerChild.  # noqa: E501
        :rtype: bool
        """
        return self._marker_show_side_bands

    @marker_show_side_bands.setter
    def marker_show_side_bands(self, marker_show_side_bands):
        """Sets the marker_show_side_bands of this MarkerChild.


        :param marker_show_side_bands: The marker_show_side_bands of this MarkerChild.  # noqa: E501
        :type: bool
        """
        if marker_show_side_bands is None:
            raise ValueError("Invalid value for `marker_show_side_bands`, must not be `None`")  # noqa: E501

        self._marker_show_side_bands = marker_show_side_bands

    @property
    def marker_show_peaks(self):
        """Gets the marker_show_peaks of this MarkerChild.  # noqa: E501


        :return: The marker_show_peaks of this MarkerChild.  # noqa: E501
        :rtype: bool
        """
        return self._marker_show_peaks

    @marker_show_peaks.setter
    def marker_show_peaks(self, marker_show_peaks):
        """Sets the marker_show_peaks of this MarkerChild.


        :param marker_show_peaks: The marker_show_peaks of this MarkerChild.  # noqa: E501
        :type: bool
        """
        if marker_show_peaks is None:
            raise ValueError("Invalid value for `marker_show_peaks`, must not be `None`")  # noqa: E501

        self._marker_show_peaks = marker_show_peaks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MarkerChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarkerChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
